'===============================================================================
' Copyright 2014 Alachisoft.  All rights reserved.
'===============================================================================


'<Summary> Represents statistics of operatin on database and NCache
Public Class Stats
    Private Shared _readTripsToDB As Int64
    Private Shared _writeTripsToDB As Int64
    Private Shared _objsReadFromDB As Int64
    Private Shared _objsWrittenToDB As Int64

    Private Shared _readTripsToDBWithCache As Int64
    Private Shared _writeTripsToDBWithCache As Int64
    Private Shared _objsReadFromDBWithCache As Int64
    Private Shared _objsWrittenToDBWithCache As Int64


    Private Shared _objsReadFromCache As Int64

    Private Shared _avgOrderLoadTime As Double
    Private Shared _avgOrderLoadTimeWithCache As Double
    Private Shared _avgOrderSaveTime As Double
    Private Shared _avgOrderSaveTimeWithCache As Double
    Public Shared Property ReadTripsToDBWithCache() As Int64
        Get
            SyncLock GetType(Stats)
                Return _readTripsToDBWithCache
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            _readTripsToDBWithCache += Value
        End Set
    End Property
    Public Shared Property WriteTripsToDBWithCache() As Int64
        Get
            SyncLock GetType(Stats)
                Return _writeTripsToDBWithCache
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            _writeTripsToDBWithCache += Value
        End Set

    End Property
    Public Shared ReadOnly Property TotalTripsToDBWithCache() As Int64
        Get
            SyncLock GetType(Stats)
                Return _readTripsToDBWithCache + _writeTripsToDBWithCache
            End SyncLock
        End Get
    End Property
    Public Shared Property ObjsReadFromDBWithCache() As Int64
        Get
            Return _objsReadFromDBWithCache
        End Get
        Set(ByVal Value As Int64)
            _objsReadFromDBWithCache += Value
        End Set
    End Property
    Public Shared Property ObjsWrittenToDBWithCache() As Int64
        Get
            SyncLock GetType(Stats)
                Return _objsWrittenToDBWithCache
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            SyncLock GetType(Stats)
                _objsWrittenToDBWithCache += Value
            End SyncLock
        End Set
    End Property


    Public Shared Property ReadTripsToDB() As Int64
        Get
            SyncLock GetType(Stats)
                Return _readTripsToDB
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            _readTripsToDB += Value
        End Set
    End Property
    Public Shared Property WriteTripsToDB() As Int64
        Get
            SyncLock GetType(Stats)
                Return _writeTripsToDB
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            _writeTripsToDB += Value
        End Set

    End Property
    Public Shared ReadOnly Property TotalTripsToDB() As Int64
        Get
            SyncLock GetType(Stats)
                Return _readTripsToDB + _writeTripsToDB
            End SyncLock
        End Get
    End Property
    Public Shared Property ObjsReadFromDB() As Int64
        Get
            Return _objsReadFromDB
        End Get
        Set(ByVal Value As Int64)
            _objsReadFromDB += Value
        End Set
    End Property
    Public Shared Property ObjsWrittenToDB() As Int64
        Get
            SyncLock GetType(Stats)
                Return _objsWrittenToDB
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            SyncLock GetType(Stats)
                _objsWrittenToDB += Value
            End SyncLock
        End Set
    End Property


    Public Shared Property ObjsReadFromCache() As Int64
        Get
            SyncLock GetType(Stats)
                Return _objsReadFromCache
            End SyncLock
        End Get
        Set(ByVal Value As Int64)
            SyncLock GetType(Stats)
                _objsReadFromCache += Value
            End SyncLock
        End Set
    End Property

    Public Shared Property CacheHitRatio() As Single
        Get
            SyncLock GetType(Stats)
                Return CacheHitRatio
            End SyncLock
        End Get
        Set(ByVal Value As Single)
            SyncLock GetType(Stats)
                CacheHitRatio = Value
            End SyncLock
        End Set
    End Property
    Public Shared Property AvgOrderFormLoadTime() As Double
        Get
            SyncLock GetType(Stats)
                Return _avgOrderLoadTime
            End SyncLock
        End Get
        Set(ByVal Value As Double)
            SyncLock GetType(Stats)
                If _avgOrderLoadTime = 0 Then
                    _avgOrderLoadTime = Value
                Else
                    _avgOrderLoadTime = (_avgOrderLoadTime + Value) / 2.0
                End If

            End SyncLock
        End Set
    End Property
    Public Shared Property AvgOrderFormLoadTimeWithCache() As Double
        Get
            SyncLock GetType(Stats)
                Return _avgOrderLoadTimeWithCache
            End SyncLock
        End Get
        Set(ByVal Value As Double)
            SyncLock GetType(Stats)
                If _avgOrderLoadTimeWithCache = 0 Then
                    _avgOrderLoadTimeWithCache = Value
                Else
                    _avgOrderLoadTimeWithCache = (_avgOrderLoadTimeWithCache + Value) / 2.0
                End If

            End SyncLock
        End Set
    End Property
    Public Shared Property AvgOrderSaveTime() As Decimal
        Get
            SyncLock GetType(Stats)
                Return _avgOrderSaveTime
            End SyncLock
        End Get
        Set(ByVal Value As Decimal)
            SyncLock GetType(Stats)
                If _avgOrderSaveTime = 0 Then
                    _avgOrderSaveTime = Value
                Else
                    _avgOrderSaveTime = (_avgOrderSaveTime + Value) / 2.0
                End If
            End SyncLock
        End Set
    End Property
    Public Shared Property AvgOrderSaveTimeWithCache() As Double
        Get
            SyncLock GetType(Stats)
                Return _avgOrderSaveTimeWithCache
            End SyncLock
        End Get
        Set(ByVal Value As Double)
            SyncLock GetType(Stats)
                If _avgOrderSaveTimeWithCache = 0 Then
                    _avgOrderSaveTimeWithCache = Value
                Else
                    _avgOrderSaveTimeWithCache = (_avgOrderSaveTimeWithCache + Value) / 2.0
                End If
            End SyncLock
        End Set
    End Property

    Public Shared Sub ResetItemsLoaded()
        _avgOrderLoadTime = 0
    End Sub
    Public Shared Sub ResetStats()
        _readTripsToDB = 0
        _writeTripsToDB = 0
        _objsReadFromDB = 0
        _objsWrittenToDB = 0

        _readTripsToDBWithCache = 0
        _writeTripsToDBWithCache = 0
        _objsReadFromDBWithCache = 0
        _objsWrittenToDBWithCache = 0

        _objsReadFromCache = 0

        _avgOrderLoadTime = 0
        _avgOrderSaveTime = 0
        _avgOrderLoadTimeWithCache = 0
        _avgOrderSaveTimeWithCache = 0

    End Sub
    Public Shared Sub ResetDBWithCacheStats()

        _readTripsToDBWithCache = 0
        _writeTripsToDBWithCache = 0
        _objsReadFromDBWithCache = 0
        _objsWrittenToDBWithCache = 0

        _objsReadFromCache = 0
    End Sub
End Class
